@@ -5,7 +5,7 @@
 -- SPDX-FileCopyrightText: Copyright (c) 2025 Objectionary.com
 -- SPDX-License-Identifier: MIT
 
-module Rule (RuleContext (..), isNF, matchProgramWithRule, meetCondition) where
+module Rule (RuleContext (..), isNF, matchProgramWithRule, matchExpressionWithRule, meetCondition) where
 
 import AST
 import Builder
@@ -44,7 +44,7 @@ matchesAnyNormalizationRule expr ctx = matchesAnyNormalizationRule' expr normali
     matchesAnyNormalizationRule' :: Expression -> [Y.Rule] -> RuleContext -> Bool
     matchesAnyNormalizationRule' _ [] _ = False
     matchesAnyNormalizationRule' expr (rule : rules) ctx =
-      let matched = unsafePerformIO (matchProgramWithRule (Program expr) rule ctx)
+      let matched = unsafePerformIO (matchExpressionWithRule expr rule ctx)
        in not (null matched) || matchesAnyNormalizationRule' expr rules ctx
 
 -- Returns True if given expression is in the normal form
@@ -278,10 +278,10 @@ extraSubstitutions substs extras RuleContext{..} = case extras of
     logDebug "Extra substitutions have been built"
     pure (catMaybes res)
 
-matchProgramWithRule :: Program -> Y.Rule -> RuleContext -> IO [Subst]
-matchProgramWithRule program rule ctx =
+matchExpressionWithRule :: Expression -> Y.Rule -> RuleContext -> IO [Subst]
+matchExpressionWithRule expr rule ctx =
   let ptn = Y.pattern rule
-      matched = matchProgram ptn program
+      matched = matchExpression ptn expr
       name = fromMaybe "unknown" (Y.name rule)
    in if null matched
         then do
@@ -304,3 +304,6 @@ matchProgramWithRule program rule ctx =
                   met <- meetMaybeCondition (Y.having rule) extended ctx
                   when (null met) (logDebug "The 'having' condition wan't met")
                   pure met
+
+matchProgramWithRule :: Program -> Y.Rule -> RuleContext -> IO [Subst]
+matchProgramWithRule (Program expr) = matchExpressionWithRule expr
