@@ -6,6 +6,7 @@
 
 module CSTSpec (spec) where
 
+import AST
 import CST
 import Control.Monad (forM_)
 import Data.Aeson
@@ -55,6 +56,26 @@ spec = do
           programToCST ast `shouldBe` cst
       )
 
+  describe "build valid CST with wrapped phiAgain{} " $ do
+    let number = BaseObject "number"
+        again = ExPhiAgain Nothing 1
+        bts = BaseObject "bytes"
+        bt = BiTau (AtAlpha 0)
+        app = ExApplication
+        form = ExFormation [BiDelta (BtMany ["40", "18", "00", "00", "00", "00", "00", "00"]), BiVoid AtRho]
+        isCSTNumber (EX_NUMBER{}) = True
+        isCSTNumber _ = False
+    forM_
+      [ ("number(bytes(data))", app number (bt (app bts (bt form))))
+      , ("again(number)(bytes(data))", app (again number) (bt (app bts (bt form))))
+      , ("number(again(bytes(data)))", app number (bt (again (app bts (bt form)))))
+      , ("number(again(bytes)(data))", app number (bt (app (again bts) (bt form))))
+      , ("again(number)(again(bytes)(data))", app (again number) (bt (app (again bts) (bt form))))
+      , ("number(bytes(again(data)))", app number (bt (app bts (bt (again form)))))
+      , ("again(number)(again(bytes)(again(data)))", app (again number) (bt (app (again bts) (bt (again form)))))
+      ]
+      (\(desc, ex) -> it desc (toCST ex 0 EOL `shouldSatisfy` isCSTNumber))
+
   describe "CST printing packs" $ do
     let resources = "test-resources/cst/printing-packs"
     packs <- runIO (allPathsIn resources)
